Crate ssh_packet

Crate ssh_packet 

Modules

arch
Types defined in the SSH’s architecture (SSH-ARCH) part of the protocol, as defined in the RFC 4251.
connect
Messages involved in the SSH’s connect (SSH-CONNECT) part of the protocol, as defined in the RFC 4254.
kex
Facilities to produce some of the exchange hashes.
sig
Facilities to interact with some of the signature algorithms.
trans
Messages involved in the SSH’s transport (SSH-TRANS) part of the protocol, as defined in the RFC 4253 and RFC 5656.
userauth
Messages involved in the SSH’s authentication (SSH-USERAUTH) part of the protocol, as defined in the RFC 4252 and RFC 4256.

Structs

Error
An error that can occur while converting from and to binary wire format.

Constants

MAX_SIZE
Maximum size for a packet, coincidentally this is the maximum size for a TCP packet.
MIN_SIZE
Minimum size for a packet, coincidentally this is the largest block cipher’s block-size.

Traits

Packet
A trait representing a packet in the SSH protocol.