Module kex
ssh_
packet
0.11.0
Module kex
Module Items
Structs
In crate ssh_
packet
ssh_packet
Module
kex
Facilities to produce some of the
exchange hashes
.
Structs

Ecdh
The exchange hash for ECDH, computed as the hash of the concatenation of the following.
Lengthed
An helper to prefix a serializable value with it’s
size
.