Module sig

Module sig 

Facilities to interact with some of the signature algorithms.

Structs

Publickey
The data that gets signed and verified to prove the possession of the said private key in the publickey authentication method, computed from the concatenation of the following.