ssh-packet
Representations of SSH packets interoperable with their binary wire representation, using binrw.
This includes a partial implementation of:
- RFC4250: SSH Protocol Assigned Numbers.
- RFC4251: SSH Protocol Architecture.
- RFC4252: SSH Authentication Protocol.
- RFC4253: SSH Transport Layer Protocol.
- RFC4254: SSH Connection Protocol.
- RFC4256: Generic Message Exchange Authentication for SSH.
- RFC5656: Elliptic Curve Algorithm Integration in the SSH Transport Layer.
Modules
- arch
- Types defined in the SSH’s architecture (
SSH-ARCH) part of the protocol, as defined in the RFC 4251. - connect
- Messages involved in the SSH’s connect (
SSH-CONNECT) part of the protocol, as defined in the RFC 4254. - kex
- Facilities to produce some of the exchange hashes.
- sig
- Facilities to interact with some of the signature algorithms.
- trans
- Messages involved in the SSH’s transport (
SSH-TRANS) part of the protocol, as defined in the RFC 4253 and RFC 5656. - userauth
- Messages involved in the SSH’s authentication (
SSH-USERAUTH) part of the protocol, as defined in the RFC 4252 and RFC 4256.
Structs
- Error
- An error that can occur while converting from and to binary wire format.
Constants
- MAX_
SIZE - Maximum size for a packet, coincidentally this is the maximum size for a TCP packet.
- MIN_
SIZE - Minimum size for a packet, coincidentally this is the largest block cipher’s block-size.
Traits
- Packet
- A trait representing a packet in the SSH protocol.